Fycondx.llDRlist.Rdtake a particular value of y and predict F(y|x)
# S3 method for llDRlist Fycondx(object, yvals, xdf)
| object | either a distribution regression or quantile regression object |
|---|---|
| yvals | the values to compute the ecdf for |
| xdf | a dataframe (can contain multiple rows) with x values |
a list of ecdfs for each row in xdf