Fycondx.rqs.Rdcompute the conditional distribution of y conditional on x using quantile regression
# S3 method for rqs Fycondx(object, yvals, xdf)
| object | a quantile regression object that has been estimated in a first step |
|---|---|
| yvals | the values to compute the ecdf for |
| xdf | a dataframe (can contain multiple rows) with x values |
a list of conditional distributions