lldrs.inner.Rdinternal function for running local linear distribution regression for a vector of y and x
lldrs.inner(y.seq, xmain.seq, Y, XMain, XOther = NULL, h = NULL, method = "level", cl = 1)
| y.seq | a vector of y values to compute F(y|x) for using local linear distribution regression |
|---|---|
| xmain.seq | a vector of x values to compute F(y|x) using local linear distribution regression |
| Y | a vector containing the data for the outcome |
| XMain | a vector containing the data for the "main" x variable |
| XOther | a matrix or data.frame containing the data for the "other" x variables |
| h | optional bandwidth |
| method | "level" or "rank" determining whether method should be used conditional on ytmin1 or the rank of ytmin1 |
| cl | The number of clusters to use, default is 1 |
a list of llDR objects that are indexed by y and t separately